@@ -1829,10 +1829,12 @@ bool Message::fromStanza(const Stanza &s, bool useTimeZoneOffset, int timeZoneOf
 			stamp.setTimeSpec(Qt::UTC);
 			d->timeStamp = stamp.toLocalTime();
 		}
+		d->timeStampSend = true;
 		d->spooled = true;
 	}
 	else {
 		d->timeStamp = QDateTime::currentDateTime();
+		d->timeStampSend = false;
 		d->spooled = false;
 	}
 
@@ -2844,13 +2846,35 @@ bool RosterItem::fromXml(const QDomElement &item)
 //---------------------------------------------------------------------------
 // Roster
 //---------------------------------------------------------------------------
+class Roster::Private
+{
+public:
+	QString groupsDelimiter;
+};
+
 Roster::Roster()
-:QList<RosterItem>()
+	: QList<RosterItem>()
+	, d(new Roster::Private)
 {
 }
 
 Roster::~Roster()
 {
+	delete d;
+}
+
+Roster::Roster(const Roster &other)
+	: QList<RosterItem>(other)
+	, d(new Roster::Private)
+{
+	d->groupsDelimiter = other.d->groupsDelimiter;
+}
+
+Roster &Roster::operator=(const Roster &other)
+{
+	QList<RosterItem>::operator=(other);
+	d->groupsDelimiter = other.d->groupsDelimiter;
+	return *this;
 }
 
 Roster::Iterator Roster::find(const Jid &j)
@@ -2873,6 +2897,16 @@ Roster::ConstIterator Roster::find(const Jid &j) const
 	return end();
 }
 
+void Roster::setGroupsDelimiter(const QString &groupsDelimiter)
+{
+	d->groupsDelimiter = groupsDelimiter;
+}
+
+QString Roster::groupsDelimiter() const
+{
+	return d->groupsDelimiter;
+}
+
 
 //---------------------------------------------------------------------------
 // FormField
