@@ -352,7 +352,7 @@ static void acceptDropAction(QDropEvent* e)
 {
 	if (e->keyboardModifiers() == Qt::NoModifier) {
 		if (e->dropAction() != Qt::MoveAction) {
-			qWarning("acceptDropAction(): e->dropAction() != Qt::MoveAction");
+			//qWarning("acceptDropAction(): e->dropAction() != Qt::MoveAction");
 			return;
 		}
 		Q_ASSERT(e->dropAction() == Qt::MoveAction);
@@ -741,7 +741,10 @@ void ContactListDragView::mousePressEvent(QMouseEvent* e)
 	}
 	ContactListView::mousePressEvent(e);
 
-	if (activateItemsOnSingleClick() && e->button() == Qt::LeftButton) {
+	static const int iconSize = 16;
+	bool iconClick = e->pos().x() < iconSize + 2;
+
+	if (( activateItemsOnSingleClick() || iconClick ) && e->button() == Qt::LeftButton) {
 		ContactListView::mouseDoubleClickEvent(e);
 	}
 }
