@@ -202,6 +202,7 @@ public:
 		dlg = d;
 		nickSeparator = ":";
 		nonAnonymous = false;
+		alert = false;
 
 		trackBar = false;
 		mCmdManager.registerProvider(this);
@@ -240,6 +241,7 @@ public:
 	int pending;
 	int hPending; // highlight pending
 	bool connecting;
+	bool alert;
 
 	QStringList hist;
 	int histAt;
@@ -547,7 +549,7 @@ public slots:
 public:
 
 	bool eventFilter( QObject *obj, QEvent *ev ) {
-		if (obj == te_log()->textWidget() || obj->parent() == te_log()->textWidget())
+		if (obj == te_log()->realTextWidget())
 		{
 			if (ev->type() == QEvent::MouseButtonPress)
 				mle()->setFocus();
@@ -730,6 +732,7 @@ GCMainDlg::GCMainDlg(PsiAccount *pa, const Jid &j, TabManager *tabManager)
 #endif
 
 	ui_.lv_users->setMainDlg(this);
+	ui_.lv_users->model()->setSupportedDragActions(Qt::CopyAction);
 	if (options->getOption("options.ui.contactlist.disable-scrollbar").toBool() ) {
 		ui_.lv_users->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 	}
@@ -885,7 +888,7 @@ GCMainDlg::GCMainDlg(PsiAccount *pa, const Jid &j, TabManager *tabManager)
 	X11WM_CLASS("groupchat");
 
 	ui_.mle->chatEdit()->setFocus();
-	logTextWidget()->installEventFilter(d);
+	ui_.log->realTextWidget()->installEventFilter(d);
 
 	// Connect signals from MUC manager
 	connect(d->mucManager,SIGNAL(action_error(MUCManager::Action, int, const QString&)), SLOT(action_error(MUCManager::Action, int, const QString&)));
@@ -1023,19 +1026,6 @@ void GCMainDlg::setShortcuts()
 	d->act_minimize->setShortcuts(ShortcutManager::instance()->shortcuts("chat.minimize"));
 }
 
-QWidget *GCMainDlg::logTextWidget()
-{
-#ifdef WEBKIT
-	return ui_.log->textWidget();
-#else
-	ChatView *logWid = ui_.log->textWidget();
-	QWidget *child = logWid->childAt(logWid->frameRect().center());
-	if (child)
-		return child;
-	return logWid;
-#endif
-}
-
 void GCMainDlg::scrollUp()
 {
 	ui_.log->scrollUp();
@@ -1072,6 +1062,7 @@ void GCMainDlg::activated()
 			u->setPending(d->pending, d->hPending);
 			account()->updateEntry(*u);
 		}
+		messagesRead(jid());
 		invalidateTab();
 	}
 	doFlash(false);
@@ -1367,6 +1358,11 @@ void GCMainDlg::reactivate() {
 	goConn();
 }
 
+void GCMainDlg::setJid(const Jid &j)
+{
+	TabbableWidget::setJid(j);
+	d->self = d->prev_self = j.resource();
+}
 
 void GCMainDlg::goConn()
 {
@@ -1705,7 +1701,7 @@ void GCMainDlg::message(const Message &_m)
 {
 	Message m = _m;
 	QString from = m.from().resource();
-	bool alert = false;
+	d->alert = false;
 
 	if (m.getMUCStatuses().contains(100)) {
 		d->nonAnonymous = true;
@@ -1755,7 +1751,7 @@ void GCMainDlg::message(const Message &_m)
 
 	// code to determine if the speaker was addressing this client in chat
 	if(m.body().contains(d->self))
-		alert = true;
+		d->alert = true;
 
 	if (m.body().left(d->self.length()) == d->self)
 		d->lastReferrer = m.from().resource();
@@ -1764,7 +1760,7 @@ void GCMainDlg::message(const Message &_m)
 		QStringList highlightWords = options->getOption("options.ui.muc.highlight-words").toStringList();
 		foreach (QString word, highlightWords) {
 			if(m.body().contains((word), Qt::CaseInsensitive)) {
-				alert = true;
+				d->alert = true;
 			}
 		}
 	}
@@ -1775,10 +1771,10 @@ void GCMainDlg::message(const Message &_m)
 			account()->playSound(PsiAccount::eSend);
 	}
 	else {
-		if(alert || (options->getOption("options.ui.notifications.sounds.notify-every-muc-message").toBool() && !m.spooled() && !from.isEmpty()) )
+		if(d->alert || (options->getOption("options.ui.notifications.sounds.notify-every-muc-message").toBool() && !m.spooled() && !from.isEmpty()) )
 			account()->playSound(PsiAccount::eGroupChat);
 
-		if(alert || (options->getOption("options.ui.notifications.passive-popups.notify-every-muc-message").toBool() && !m.spooled() && !from.isEmpty()) ) {
+		if(d->alert || (options->getOption("options.ui.notifications.passive-popups.notify-every-muc-message").toBool() && !m.spooled() && !from.isEmpty()) ) {
 			if (!m.spooled() && !isActiveTab() && !m.from().resource().isEmpty()) {
 				XMPP::Jid jid = m.from()/*.withDomain("")*/;
 				MessageEvent *e = new MessageEvent(m, account());
@@ -1791,9 +1787,9 @@ void GCMainDlg::message(const Message &_m)
 	}
 
 	if(from.isEmpty())
-		appendSysMsg(m.body(), alert, m.timeStamp());
+		appendSysMsg(m.body(), d->alert, m.timeStamp());
 	else
-		appendMessage(m, alert);
+		appendMessage(m, d->alert);
 }
 
 void GCMainDlg::joined()
@@ -1830,6 +1826,11 @@ const QDateTime & GCMainDlg::lastMsgTime() const
 	return d->te_log()->lastMsgTime();
 }
 
+bool GCMainDlg::isLastMessageAlert() const
+{
+	return d->alert;
+}
+
 void GCMainDlg::appendSysMsg(const QString &str, bool alert, const QDateTime &ts)
 {
 	MessageView mv = MessageView::fromPlainText(str, MessageView::System);
@@ -2056,11 +2057,11 @@ void GCMainDlg::lv_action(const QString &nick, const Status &s, int x)
 		d->mucManager->ban(contact->s.mucItem().jid());
 	}
 	else if(x > 11 && x < 19) {
-		MUCReasonsEditor *editor = new MUCReasonsEditor(this);
+		MUCReasonsEditor editor(this);
 		QString reason;
-		if (editor->exec())
-			reason = editor->reason();
-		delete editor;
+		if (editor.exec())
+			reason = editor.reason();
+		else return;
 		GCUserViewItem *contact = (GCUserViewItem*) ui_.lv_users->findEntry(nick);
 		if (!contact)
 			return;
