@@ -76,9 +76,11 @@ public:
 	const QString& nick() const;
 	const QString& topic() const;
 	const QDateTime& lastMsgTime() const;
+	bool isLastMessageAlert() const;
 
 	bool isInactive() const;
 	void reactivate();
+	void setJid(const Jid &j);
 
 	// reimplemented
 	virtual TabbableWidget::State state() const;
@@ -88,7 +90,6 @@ public:
 
 protected:
 	void setShortcuts();
-	QWidget *logTextWidget();
 
 	// reimplemented
 	void resizeEvent(QResizeEvent *e);
@@ -100,6 +101,7 @@ protected:
 
 signals:
 	void aSend(const Message &);
+	void messagesRead(const Jid &);
 
 public slots:
 	// reimplemented
@@ -174,9 +176,10 @@ private:
 
 	void contextMenuEvent(QContextMenuEvent *);
 
-
 	void setMargins();
+
 	inline XMPP::Jid jidForNick(const QString &nick) const;
+
 };
 
 class GCFindDlg : public QDialog
