@@ -1681,6 +1681,7 @@ void MainWin::toggleVisible(bool fromTray)
 
 void MainWin::setTrayToolTip(const Status& status, bool, bool)
 {
+	Q_UNUSED (status);
 	if (!d->tray) {
 		return;
 	}
@@ -1787,8 +1788,6 @@ void MainWin::updateTray()
 
 	buildTrayMenu();
 	d->tray->setContextMenu(d->trayMenu);
-
-	d->tray->iconsetChanged(PsiOptions::instance()->getOption("options.iconsets.status").toString());
 }
 
 void MainWin::doRecvNextEvent()
