@@ -113,7 +113,9 @@ PsiOtrPlugin::PsiOtrPlugin()
       m_accountHost(NULL),
       m_accountInfo(NULL),
       m_contactInfo(NULL),
-      m_iconHost(NULL)
+      m_iconHost(NULL),
+      m_psiEvent(NULL),
+      m_messageBoxList()
 {
 }
 
@@ -127,7 +129,7 @@ PsiOtrPlugin::~PsiOtrPlugin()
 
 QString PsiOtrPlugin::name() const
 {
-    return "Off-the-Record Messaging";
+    return "Off-the-Record Messaging Plugin";
 }
 
 // ---------------------------------------------------------------------------
@@ -141,7 +143,7 @@ QString PsiOtrPlugin::shortName() const
 
 QString PsiOtrPlugin::version() const
 {
-    return "0.9.9";
+    return "1.0.2";
 }
 
 // ---------------------------------------------------------------------------
@@ -204,6 +206,11 @@ bool PsiOtrPlugin::disable()
     }
     m_onlineUsers.clear();
 
+    while (!m_messageBoxList.empty()) {
+        qDeleteAll(m_messageBoxList.begin(), m_messageBoxList.end());
+        m_messageBoxList.clear();
+    }
+
     delete m_otrConnection;
     m_enabled = false;
     return true;
@@ -484,6 +491,11 @@ void PsiOtrPlugin::setIconFactoryAccessingHost(IconFactoryAccessingHost* host)
     m_iconHost = host;
 }
 
+//-----------------------------------------------------------------------------
+void PsiOtrPlugin::setEventCreatingHost(EventCreatingHost *host) {
+    m_psiEvent = host;
+}
+
 //-----------------------------------------------------------------------------
 
 bool PsiOtrPlugin::incomingStanza(int accountIndex, const QDomElement& xml)
@@ -619,7 +631,8 @@ bool PsiOtrPlugin::isLoggedIn(const QString& account, const QString& contact)
 
 //-----------------------------------------------------------------------------
 
-void PsiOtrPlugin::notifyUser(const OtrNotifyType& type, const QString& message)
+void PsiOtrPlugin::notifyUser(const QString& account, const QString& contact,
+                              const QString& message, const OtrNotifyType& type)
 {
     QMessageBox::Icon messageBoxIcon;
     if (type == OTR_NOTIFY_ERROR)
@@ -635,9 +648,27 @@ void PsiOtrPlugin::notifyUser(const OtrNotifyType& type, const QString& message)
         messageBoxIcon = QMessageBox::Information;
     }
 
-    QMessageBox mb(messageBoxIcon, tr("Psi OTR"), message, QMessageBox::Ok, NULL,
-                   Qt::Dialog | Qt::MSWindowsFixedSizeDialogHint);
-    mb.exec();
+    QMessageBox *messageBox = new QMessageBox(messageBoxIcon, tr("Psi OTR"), message,
+                                              QMessageBox::Ok, NULL,
+                                              Qt::Dialog | Qt::MSWindowsFixedSizeDialogHint);
+    m_messageBoxList.enqueue(messageBox);
+
+    m_psiEvent->createNewEvent(getAccountIndexById(account), contact,
+                               tr("OTR Plugin: event from %1").arg(contact),
+                               this, SLOT(eventActivated()));
+}
+
+//-----------------------------------------------------------------------------
+
+void PsiOtrPlugin::eventActivated()
+{
+    if (!m_messageBoxList.empty()) {
+        QMessageBox *messageBox = m_messageBoxList.dequeue();
+        if (messageBox) {
+            messageBox->exec();
+            delete messageBox;
+        }
+    }
 }
 
 //-----------------------------------------------------------------------------
