@@ -175,8 +175,8 @@ private:
 
 
 PsiChatDlg::PsiChatDlg(const Jid& jid, PsiAccount* pa, TabManager* tabManager)
-	: ChatDlg(jid, pa, tabManager), mCmdManager_(&mCmdSite_), tabCompletion(&mCmdManager_), autoPGP_(true)
-	, actions_(new ActionList("", 0, false))
+	: ChatDlg(jid, pa, tabManager), actions_(new ActionList("", 0, false)), mCmdManager_(&mCmdSite_), tabCompletion(&mCmdManager_)
+	, autoPGP_(true)
 {
 	connect(account()->psi(), SIGNAL(accountCountChanged()), this, SLOT(updateIdentityVisibility()));
 	connect(account(), SIGNAL(addedContact(PsiContact*)), SLOT(updateContactAdding(PsiContact*)));
@@ -301,6 +301,8 @@ void PsiChatDlg::initUi()
 	setMargins();
 
 	connect(ui_.log->textWidget(), SIGNAL(quote(const QString &)), ui_.mle->chatEdit(), SLOT(insertAsQuote(const QString &)));
+ 
+	ui_.log->realTextWidget()->installEventFilter(this);
 
 #ifdef PSI_PLUGINS
 	PluginManager::instance()->setupChatTab(this, account(), jid().full());
@@ -999,15 +1001,22 @@ void PsiChatDlg::doMinimize()
 }
 
 bool PsiChatDlg::eventFilter( QObject *obj, QEvent *ev ) {
-	if ( obj == chatEdit() && ev->type() == QEvent::KeyPress ) {
-		QKeyEvent *e = (QKeyEvent *)ev;
+	if ( obj == chatEdit() ) {
+		if ( ev->type() == QEvent::KeyPress ) {
+			QKeyEvent *e = (QKeyEvent *)ev;
 
-		if ( e->key() == Qt::Key_Tab ) {
-			tabCompletion.tryComplete();
-			return true;
+			if ( e->key() == Qt::Key_Tab ) {
+				tabCompletion.tryComplete();
+				return true;
+			}
+
+			tabCompletion.reset();
 		}
+	}
 
-		tabCompletion.reset();
+	else if ( obj == ui_.log->realTextWidget() ) {
+		if ( ev->type() == QEvent::MouseButtonPress )
+			chatEdit()->setFocus();
 	}
 
 	return ChatDlg::eventFilter( obj, ev );
