@@ -81,6 +81,9 @@
 #include "accountscombobox.h"
 #include "tabdlg.h"
 #include "chatdlg.h"
+#ifdef GROUPCHAT
+#include "groupchatdlg.h"
+#endif
 #include "spellchecker/aspellchecker.h"
 #ifdef WEBKIT
 #include "avatars.h"
@@ -505,7 +508,7 @@ bool PsiCon::init()
 #elif defined(USE_QDCHECKER)
 	d->autoUpdater = new QDChecker();
 #endif
-	if (options->getOption("options.auto-update.check-on-startup").toBool() && d->autoUpdater)
+	if (PsiOptions::instance()->getOption("options.auto-update.check-on-startup").toBool() && d->autoUpdater)
 		d->autoUpdater->checkForUpdates();
 
 	d->iconSelect = new IconSelectPopup(0);
@@ -579,10 +582,6 @@ bool PsiCon::init()
 		d->mainwin->show();
 	}
 
-#ifdef FILETRANSFER
-	d->ftwin = new FileTransDlg(this);
-#endif
-
 	connect(&d->idle, SIGNAL(secondsIdle(int)), SLOT(secondsIdle(int)));
 
 	//PopupDurationsManager
@@ -790,6 +789,7 @@ void PsiCon::deinit()
 
 #ifdef FILETRANSFER
 	delete d->ftwin;
+	d->ftwin = NULL;
 #endif
 
 	if(d->mainwin) {
@@ -840,9 +840,11 @@ EDB *PsiCon::edb() const
 	return d->edb;
 }
 
-FileTransDlg *PsiCon::ftdlg() const
+FileTransDlg *PsiCon::ftdlg()
 {
 #ifdef FILETRANSFER
+	if (!d->ftwin)
+		d->ftwin = new FileTransDlg(this);
 	return d->ftwin;
 #else
 	return 0;
@@ -932,20 +934,25 @@ void PsiCon::doNewBlankMessage()
 	if(!account)
 		return;
 
-	EventDlg *w = createEventDlg("", account);
+	EventDlg *w = createMessageDlg("", account);
 	if (!w)
 		return;
 
 	w->show();
 }
 
-// FIXME: smells fishy. Refactor! Probably create a common class for all dialogs and
-// call optionsUpdate() automatically.
-EventDlg *PsiCon::createEventDlg(const QString &to, PsiAccount *pa)
+EventDlg *PsiCon::createMessageDlg(const QString &to, PsiAccount *pa)
 {
 	if (!EventDlg::messagingEnabled())
 		return 0;
 
+	return createEventDlg(to, pa);
+}
+
+// FIXME: smells fishy. Refactor! Probably create a common class for all dialogs and
+// call optionsUpdate() automatically.
+EventDlg *PsiCon::createEventDlg(const QString &to, PsiAccount *pa)
+{
 	EventDlg *w = new EventDlg(to, this, pa);
 	connect(this, SIGNAL(emitOptionsUpdate()), w, SLOT(optionsUpdate()));
 	return w;
@@ -1286,7 +1293,7 @@ void PsiCon::doOptions()
 void PsiCon::doFileTransDlg()
 {
 #ifdef FILETRANSFER
-	bringToFront(d->ftwin);
+	bringToFront(ftdlg());
 #endif
 }
 
@@ -1745,31 +1752,28 @@ void PsiCon::processEvent(PsiEvent *e, ActivationType activationType)
 	}
 
 	bool isChat = false;
+#ifdef GROUPCHAT
+	bool isMuc = false;
+#endif
 	bool sentToChatWindow = false;
 	if ( e->type() == PsiEvent::Message ) {
 		MessageEvent *me = (MessageEvent *)e;
 		const Message &m = me->message();
-		bool emptyForm = m.getForm().fields().empty();
-		// FIXME: Refactor this, PsiAccount and PsiEvent out
-		if ((m.type() == "chat" && emptyForm)
-			|| !EventDlg::messagingEnabled()) {
-			isChat = true;
-			sentToChatWindow = me->sentToChatWindow();
+#ifdef GROUPCHAT
+		if (m.type() == "groupchat") {
+			isMuc = true;
 		}
-	}
-
-	if (e->type() == PsiEvent::Auth && !EventDlg::messagingEnabled()) {
-		if (static_cast<AuthEvent*>(e)->authType() == "subscribe") {
-#ifdef YAPSI
-			bringToFront(d->mainwin);
-			return;
-#else
-			e->account()->dj_addAuth(e->jid());
+		else {
 #endif
+			bool emptyForm = m.getForm().fields().empty();
+			// FIXME: Refactor this, PsiAccount and PsiEvent out
+			if (m.type() == "chat" && emptyForm) {
+				isChat = true;
+				sentToChatWindow = me->sentToChatWindow();
+			}
+#ifdef GROUPCHAT
 		}
-		e->account()->eventQueue()->dequeue(e);
-		delete e;
-		return;
+#endif
 	}
 
 	if ( isChat ) {
@@ -1802,6 +1806,17 @@ void PsiCon::processEvent(PsiEvent *e, ActivationType activationType)
 	}
 #endif
 	else {
+#ifdef GROUPCHAT
+		if (isMuc) {
+			PsiAccount *account = e->account();
+			GCMainDlg *c = account->findDialog<GCMainDlg*>(e->from());
+			if (c) {
+				c->ensureTabbedCorrectly();
+				c->bringToFront(true);
+				return;
+			}
+		}
+#endif
 		// search for an already opened eventdlg
 		EventDlg *w = e->account()->findDialog<EventDlg*>(u->jid());
 
