@@ -150,7 +150,7 @@ public:
 			bool found = false;
 
 
-			foreach(QVariant serviceV, PsiOptions::instance()->mapKeyList("options.iconsets.service-status")) {
+			foreach(const QVariant& serviceV, PsiOptions::instance()->mapKeyList("options.iconsets.service-status")) {
 				QString service = serviceV.toString();
 				if (services.contains(service)) {
 					if (services[service].indexIn(jid.domain()) != -1 ) {
@@ -188,14 +188,16 @@ public:
 		// third level -- custom icons
 
 		QStringList customicons = PsiOptions::instance()->getChildOptionNames("options.iconsets.custom-status", true, true);
-		foreach(QString base, customicons) {
+		foreach(const QString& base, customicons) {
 			QRegExp rx = QRegExp(PsiOptions::instance()->getOption(base + ".regexp").toString());
 			if ( rx.indexIn(jid.bare()) != -1 ) {
 				const Iconset *is = psi->roster.value(PsiOptions::instance()->getOption(base + ".iconset").toString());
 				if ( is ) {
 					PsiIcon *i = (PsiIcon *)is->icon(iconName);
-					if ( i )
-						icon = (PsiIcon *)is->icon(iconName);
+					if ( i ) {
+						icon = i;
+						break;
+					}
 				}
 			}
 		}
@@ -648,7 +650,7 @@ PsiIcon *PsiIconset::event2icon(PsiEvent *e)
 		const Message &m = me->message();
 		if(m.type() == "headline")
 			icon = "psi/headline";
-		else if(m.type() == "chat")
+		else if(m.type() == "chat" || m.type() == "groupchat")
 			icon = "psi/chat";
 		else if(m.type() == "error")
 			icon = "psi/system";
